@@ -6,15 +6,12 @@ use crate::{
     types::{ManagedBuffer, ManagedType, ManagedVec},
 };
 
-pub fn event_topic_accumulator<A>(
-    api: A,
-    event_identifier: &[u8],
-) -> ManagedVec<A, ManagedBuffer<A>>
+pub fn event_topic_accumulator<A>(event_identifier: &[u8]) -> ManagedVec<A, ManagedBuffer<A>>
 where
     A: ErrorApi + ManagedTypeApi,
 {
-    let mut accumulator = ManagedVec::new(api.clone());
-    accumulator.push(ManagedBuffer::new_from_bytes(api, event_identifier));
+    let mut accumulator = ManagedVec::new();
+    accumulator.push(ManagedBuffer::new_from_bytes(event_identifier));
     accumulator
 }
 
@@ -23,7 +20,7 @@ where
     A: ErrorApi + ManagedTypeApi,
     T: TopEncode,
 {
-    let mut topic_buffer = ManagedBuffer::new(accumulator.type_manager());
+    let mut topic_buffer = ManagedBuffer::new();
     topic.top_encode_or_exit(
         &mut topic_buffer,
         accumulator.type_manager(),
@@ -37,8 +34,7 @@ fn serialize_log_topic_exit<A>(api: A, encode_err: EncodeError) -> !
 where
     A: ErrorApi + ManagedTypeApi + 'static,
 {
-    let mut message_buffer =
-        ManagedBuffer::new_from_bytes(api.clone(), err_msg::LOG_TOPIC_ENCODE_ERROR);
+    let mut message_buffer = ManagedBuffer::<A>::new_from_bytes(err_msg::LOG_TOPIC_ENCODE_ERROR);
     message_buffer.append_bytes(encode_err.message_bytes());
     api.signal_error_from_buffer(message_buffer.get_raw_handle())
 }
@@ -48,7 +44,7 @@ where
     T: TopEncode,
     A: ErrorApi + ManagedTypeApi + Clone + 'static,
 {
-    let mut data_buffer = ManagedBuffer::new(api.clone());
+    let mut data_buffer = ManagedBuffer::new();
     data.top_encode_or_exit(&mut data_buffer, api, serialize_log_data_exit);
     data_buffer
 }
@@ -58,8 +54,7 @@ fn serialize_log_data_exit<A>(api: A, encode_err: EncodeError) -> !
 where
     A: ErrorApi + ManagedTypeApi + 'static,
 {
-    let mut message_buffer =
-        ManagedBuffer::new_from_bytes(api.clone(), err_msg::LOG_DATA_ENCODE_ERROR);
+    let mut message_buffer = ManagedBuffer::<A>::new_from_bytes(err_msg::LOG_DATA_ENCODE_ERROR);
     message_buffer.append_bytes(encode_err.message_bytes());
     api.signal_error_from_buffer(message_buffer.get_raw_handle())
 }
