@@ -3,6 +3,7 @@ use core::marker::PhantomData;
 use super::{ManagedBuffer, ManagedType};
 use crate::{
     api::{Handle, ManagedTypeApi},
+    hex_util::encode_bytes_as_hex,
     types::BoxedBytes,
 };
 use alloc::string::String;
@@ -11,7 +12,6 @@ use elrond_codec::{
     TopDecode, TopDecodeInput, TopEncode, TopEncodeOutput, TryStaticCast,
 };
 
-#[derive(Debug)]
 pub struct BigUint<M: ManagedTypeApi> {
     pub(crate) handle: Handle,
     _phantom: PhantomData<M>,
@@ -203,3 +203,15 @@ impl<M: ManagedTypeApi> crate::abi::TypeAbi for BigUint<M> {
         String::from("BigUint")
     }
 }
+
+impl<M: ManagedTypeApi> core::fmt::Debug for BigUint<M> {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        f.debug_struct("BigUint")
+            .field("handle", &self.handle)
+            .field(
+                "hex-value-be",
+                &encode_bytes_as_hex(&self.to_bytes_be().as_slice()),
+            )
+            .finish()
+    }
+}
