@@ -14,7 +14,6 @@ use elrond_codec::{
 /// A list of items that lives inside a managed buffer.
 /// Items can be either stored there in full (e.g. `u32`),
 /// or just via handle (e.g. `BigUint<M>`).
-#[derive(Debug)]
 pub struct ManagedVec<M, T>
 where
     M: ManagedTypeApi,
@@ -175,9 +174,9 @@ where
 
     /// Temporarily converts self to a `Vec<T>`.
     /// All operations performed on the temporary vector get saved back to the underlying buffer.
-    pub fn with_self_as_vec<F>(&mut self, f: F)
+    pub fn with_self_as_vec<R, F>(&mut self, f: F) -> R
     where
-        F: FnOnce(&mut Vec<T>),
+        F: FnOnce(&mut Vec<T>) -> R,
     {
         let new = ManagedVec::new();
         let old = core::mem::replace(self, new);
@@ -185,10 +184,11 @@ where
         for item in old.into_iter() {
             temp_vec.push(item);
         }
-        f(&mut temp_vec);
+        let result = f(&mut temp_vec);
         for new_item in temp_vec {
             self.push(new_item);
         }
+        result
     }
 
     pub fn iter(&self) -> ManagedVecIterator<M, T> {
@@ -350,3 +350,17 @@ pub fn managed_vec_from_slice_of_boxed_bytes<M: ManagedTypeApi>(
     }
     result
 }
+
+impl<M, T> core::fmt::Debug for ManagedVec<M, T>
+where
+    M: ManagedTypeApi,
+    T: ManagedVecItem + core::fmt::Debug + Clone,
+{
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        let mut dbg_list = f.debug_list();
+        for item in self.into_iter() {
+            dbg_list.entry(&item);
+        }
+        dbg_list.finish()
+    }
+}
